@@ -19,11 +19,16 @@
  * Author: Ryan Lortie <desrt@desrt.ca>
  */
 
+#ifndef __dconf_rebuilder_h__
+#define __dconf_rebuilder_h__
+
 #include <glib.h>
 
 gboolean dconf_rebuilder_rebuild (const gchar  *filename,
                                   const gchar  *prefix,
-                                  const gchar **keys,
-                                  GVariant    **values,
+                                  const gchar *const*keys,
+                                  GVariant    *const*values,
                                   gint          n_items,
                                   GError      **error);
+
+#endif /* __dconf_rebuilder_h__ */
